@@ -37,8 +37,8 @@ complex_dotprod_generic (const short *input,
     const gr_complex tap0(taps[0], taps[1]);
     const gr_complex tap1(taps[2], taps[3]);
 
-    sum0 += input[0] * tap0;
-    sum1 += input[1] * tap1;
+    sum0 += (float)input[0] * tap0;
+    sum1 += (float)input[1] * tap1;
 
     input += 4;
     taps += 8;
