@@ -1,5 +1,5 @@
 #
-# Copyright 2003 Free Software Foundation, Inc.
+# Copyright 2003,2005 Free Software Foundation, Inc.
 # 
 # This file is part of GNU Radio
 # 
@@ -27,5 +27,5 @@ fir_signatures = [ 'ccf', 'fcc', 'ccc', 'fff', 'scc', 'fsf' ]
 
 ## -----------------------------------------------------------------------
 
-from gnuradio.build_utils import expand_template, copyright, open_and_log_name, standard_dict
-from gnuradio.build_utils_codes import *
+from build_utils import expand_template, copyright, open_and_log_name, standard_dict
+from build_utils_codes import *
