@@ -20,8 +20,8 @@
 # Boston, MA 02111-1307, USA.
 # 
 
-from gnuradio.build_utils import expand_template, standard_dict
-from gnuradio.build_utils_codes import *
+from build_utils import expand_template, standard_dict
+from build_utils_codes import *
 
 import re
 
@@ -45,7 +45,8 @@ reg_roots = [
     'gr_add_XX',
     'gr_sub_XX',
     'gr_multiply_XX',
-    'gr_divide_XX'
+    'gr_divide_XX',
+    'gr_mute_XX'
     ]
 
 
