@@ -51,6 +51,19 @@ gr_simple_framer::gr_simple_framer (int payload_bytesize)
   set_output_multiple (d_output_block_size);
 }
 
+void
+gr_simple_framer::forecast (int noutput_items, gr_vector_int &ninput_items_required)
+{
+  assert (noutput_items % d_output_block_size == 0);
+
+  int	nblocks = noutput_items / d_output_block_size;
+  int	input_required = nblocks * d_input_block_size;
+
+  unsigned ninputs = ninput_items_required.size();
+  for (unsigned int i = 0; i < ninputs; i++)
+    ninput_items_required[i] = input_required;
+}
+
 int
 gr_simple_framer::general_work (int noutput_items,
 				gr_vector_int &ninput_items,
@@ -60,12 +73,10 @@ gr_simple_framer::general_work (int noutput_items,
   const unsigned char *in = (const unsigned char *) input_items[0];
   unsigned char *out = (unsigned char *) output_items[0];
 
-  assert (noutput_items % d_output_block_size == 0);
-
   int n = 0;
   int nblocks = 0;
 
-  memset (out, 0, noutput_items);
+  memset (out, 0x55, noutput_items);
 
   while (n < noutput_items){
     out[0] = (GRSF_SYNC >> 24) & 0xff;
