@@ -28,6 +28,8 @@
 #include <qa_general.h>
 #include <qa_gr_firdes.h>
 #include <qa_gr_circular_file.h>
+#include <qa_gr_fxpt.h>
+#include <qa_gr_fxpt_nco.h>
 
 CppUnit::TestSuite *
 qa_general::suite ()
@@ -36,6 +38,8 @@ qa_general::suite ()
 
   s->addTest (qa_gr_firdes::suite ());
   s->addTest (qa_gr_circular_file::suite ());
+  s->addTest (qa_gr_fxpt::suite ());
+  s->addTest (qa_gr_fxpt_nco::suite ());
   
   return s;
 }
