@@ -230,7 +230,7 @@ standard_tests (gr_vmcircbuf_factory *f, int verbose)
   }
 
   if (verbose >= 1)
-    fprintf (stderr, "....... %s: %s", f->name (), ok ? "OK\n" : "Failed\n");
+    fprintf (stderr, "....... %s: %s", f->name (), ok ? "OK\n" : "Doesn't work\n");
 
   return ok;
 }
@@ -249,7 +249,7 @@ gr_vmcircbuf_sysconfig::test_factory (gr_vmcircbuf_factory *f, int verbose)
   }
   catch (gr_signal &sig){
     if (verbose){
-      fprintf (stderr, "....... %s: %s", f->name (), "Failed\n");
+      fprintf (stderr, "....... %s: %s", f->name (), "Doesn't work\n");
       fprintf (stderr,
 	       "gr_vmcircbuf_factory::test_factory (%s): caught %s\n",
 	       f->name (), sig.name().c_str());
@@ -258,13 +258,14 @@ gr_vmcircbuf_sysconfig::test_factory (gr_vmcircbuf_factory *f, int verbose)
   }
   catch (...){
     if (verbose){
-      fprintf (stderr, "....... %s: %s", f->name (), "Failed\n");
+      fprintf (stderr, "....... %s: %s", f->name (), "Doesn't work\n");
       fprintf (stderr,
 	       "gr_vmcircbuf_factory::test_factory (%s): some kind of uncaught exception\n",
 	       f->name ());
     }
     return false;
   }
+  return false;			// never gets here.  shut compiler up.
 }
 
 bool
