@@ -38,6 +38,7 @@ class gr_add_const_ss;
 class gr_add_ff;
 class gr_add_ii;
 class gr_add_ss;
+class gr_base_error_handler;
 class gr_block;
 class gr_bytes_to_syms;
 class gr_check_counting_s;
@@ -52,12 +53,15 @@ class gr_divide_cc;
 class gr_divide_ff;
 class gr_divide_ii;
 class gr_divide_ss;
+class gr_error_handler;
 class gr_fft_vcc;
 class gr_fft_vfc;
 class gr_file_descriptor_sink;
 class gr_file_descriptor_source;
+class gr_file_error_handler;
 class gr_file_sink;
 class gr_file_source;
+class gr_filter_delay_fc;
 class gr_fir_filter_ccc;
 class gr_fir_filter_ccf;
 class gr_fir_filter_fcc;
@@ -86,6 +90,8 @@ class gr_interp_fir_filter_fsf;
 class gr_interp_fir_filter_scc;
 class gr_keep_one_in_n;
 class gr_lfsr_32k_source_s;
+class gr_msg_handler;
+class gr_msg_queue;
 class gr_multiply_cc;
 class gr_multiply_const_cc;
 class gr_multiply_const_ff;
@@ -94,6 +100,11 @@ class gr_multiply_const_ss;
 class gr_multiply_ff;
 class gr_multiply_ii;
 class gr_multiply_ss;
+class gr_mute_cc;
+class gr_mute_ff;
+class gr_mute_ii;
+class gr_mute_ss;
+class gr_nlog10_ff;
 class gr_noise_source_c;
 class gr_noise_source_f;
 class gr_noise_source_i;
@@ -103,7 +114,10 @@ class gr_null_sink;
 class gr_null_source;
 class gr_oscope_sink_f;
 class gr_oscope_sink_x;
+class gr_parallel_to_serial;
 class gr_quadrature_demod_cf;
+class gr_rms_cf;
+class gr_rms_ff;
 class gr_serial_to_parallel;
 class gr_short_to_float;
 class gr_sig_source_c;
@@ -112,6 +126,8 @@ class gr_sig_source_i;
 class gr_sig_source_s;
 class gr_simple_correlator;
 class gr_simple_framer;
+class gr_simple_squelch_cc;
+class gr_single_pole_iir_filter_ff;
 class gr_sub_cc;
 class gr_sub_ff;
 class gr_sub_ii;
