@@ -33,7 +33,7 @@ __all__ = ['source', 'sink']
 source = None
 sink = None
 
-verbose = True
+verbose = False
 
 def __init__ ():
     global source, sink
