@@ -28,6 +28,5 @@ from gnuradio_swig_python import *
 from basic_flow_graph import *
 from flow_graph import *
 from exceptions import *
-
-# soon to be goners...
-# from sdr_1000 import sdr_1000
+from hier_block import *
+# from gnuradio.blks import *
