@@ -21,6 +21,7 @@
 
 from gnuradio_swig_python import gr_block_sptr
 import types
+import hier_block
 
 def remove_duplicates (seq):
     new = []
@@ -44,6 +45,31 @@ class endpoint (object):
     def __str__ (self):
         return '<endpoint (%s, %s)>' % (self.block, self.port)
         
+def expand_src_endpoint (src_endpoint):
+    # A src_endpoint is an output of a block
+    src_endpoint = coerce_endpoint (src_endpoint)
+    if isinstance (src_endpoint.block, hier_block.hier_block_base):
+        return expand_src_endpoint (
+            coerce_endpoint (src_endpoint.block.resolve_output_port(src_endpoint.port)))
+    else:
+        return src_endpoint
+
+def expand_dst_endpoint (dst_endpoint):
+    # a dst_endpoint is the input to a block
+    dst_endpoint = coerce_endpoint (dst_endpoint)
+    if isinstance (dst_endpoint.block, hier_block.hier_block_base):
+        exp = [coerce_endpoint(x) for x in
+               dst_endpoint.block.resolve_input_port(dst_endpoint.port)]
+        return expand_dst_endpoints (exp)
+    else:
+        return [dst_endpoint]
+
+def expand_dst_endpoints (endpoint_list):
+    r = []
+    for e in endpoint_list:
+        r.extend (expand_dst_endpoint (e))
+    return r
+           
 
 def coerce_endpoint (x):
     if isinstance (x, endpoint):
@@ -52,8 +78,10 @@ def coerce_endpoint (x):
         return endpoint (x[0], x[1])
     elif hasattr (x, 'block'):          # assume it's a block
         return endpoint (x, 0)
+    elif isinstance(x, hier_block.hier_block_base):
+        return endpoint (x, 0)
     else:
-        raise ValueError, "Not coercible to endpoint: " % (x,)
+        raise ValueError, "Not coercible to endpoint: %s" % (x,)
     
 
 class edge (object):
@@ -76,7 +104,21 @@ class basic_flow_graph (object):
     def __init__ (self):
         self.edge_list = []
 
-    def connect (self, src_endpoint, dst_endpoint):
+    def connect (self, *points):
+        '''connect requires two or more arguments that can be coerced to endpoints.
+        If more than two arguments are provided, they are connected together successively.
+        '''
+        if len (points) < 2:
+            raise ValueError, ("connect requires at least two endpoints; %d provided." % (len (points),))
+        for i in range (1, len (points)):
+            self._connect (points[i-1], points[i])
+
+    def _connect (self, src_endpoint, dst_endpoint):
+        s = expand_src_endpoint (src_endpoint)
+        for d in expand_dst_endpoint (dst_endpoint):
+            self._connect_prim (s, d)
+
+    def _connect_prim (self, src_endpoint, dst_endpoint):
         src_endpoint = coerce_endpoint (src_endpoint)
         dst_endpoint = coerce_endpoint (dst_endpoint)
         self._check_valid_src_port (src_endpoint)
@@ -84,9 +126,13 @@ class basic_flow_graph (object):
         self._check_dst_in_use (dst_endpoint)
         self._check_type_match (src_endpoint, dst_endpoint)
         self.edge_list.append (edge (src_endpoint, dst_endpoint))
-        None
 
     def disconnect (self, src_endpoint, dst_endpoint):
+        s = expand_src_endpoint (src_endpoint)
+        for d in expand_dst_endpoint (dst_endpoint):
+            self._disconnect_prim (s, d)
+
+    def _disconnect_prim (self, src_endpoint, dst_endpoint):
         src_endpoint = coerce_endpoint (src_endpoint)
         dst_endpoint = coerce_endpoint (dst_endpoint)
         e = edge (src_endpoint, dst_endpoint)
