@@ -46,8 +46,8 @@ class buffer_sizes (object):
         """allocate buffer for output index of block m"""
         item_size = m.output_signature().sizeof_stream_item (index)
         nitems = self.fixed_buffer_size / item_size
-        if 1 + m.output_multiple () > nitems:
-            nitems = 1 + m.output_multiple ()
+        if nitems < 2 * m.output_multiple ():
+            nitems = 2 * m.output_multiple ()
             
         return buffer (nitems, item_size)
     
@@ -103,8 +103,14 @@ class flow_graph (basic_flow_graph):
 
     def _assign_details (self):
         for m in self.blocks:
-            ninputs = len (self.in_edges (m))
-            noutputs = len (self.out_edges (m))
+            edges = self.in_edges (m)
+            used_ports = remove_duplicates ([e.dst.port for e in edges])
+            ninputs = len (used_ports)
+
+            edges = self.out_edges (m)
+            used_ports = remove_duplicates ([e.src.port for e in edges])
+            noutputs = len (used_ports)
+
             m.set_detail (block_detail (ninputs, noutputs))
 
     def _assign_buffers (self):
